@@ -33,12 +33,14 @@
 
 void pygst_register_classes (PyObject *d);
 void pygst_add_constants(PyObject *module, const gchar *strip_prefix);
+void _pygst_register_boxed_types(PyObject *moddict);
 		
 extern PyMethodDef pygst_functions[];
 extern GSList *mainloops;
 extern void _pygst_main_quit(void);
 extern PyObject *PyGstExc_LinkError;
 
+GST_DEBUG_CATEGORY (gst_python);
 
 /* This is a timeout that gets added to the mainloop to handle SIGINT (Ctrl-C)
  * Other signals get handled at some other point where transition from
@@ -67,7 +69,7 @@ static void
 sink_gstobject(GObject *object)
 {
      if (GST_OBJECT_FLOATING(object)) {
-	  g_object_ref(object);
+	  gst_object_ref(GST_OBJECT(object));
 	  gst_object_sink(GST_OBJECT(object));
      }
 }
@@ -114,6 +116,7 @@ init_gst (void)
 	  g_free (argv);
      }
 
+     _pygst_register_boxed_types (NULL);
      pygobject_register_sinkfunc(GST_TYPE_OBJECT, sink_gstobject);
 
      m = Py_InitModule ("_gst", pygst_functions);
@@ -135,6 +138,8 @@ init_gst (void)
      PyModule_AddIntConstant(m, "MSECOND", GST_MSECOND);
      PyModule_AddIntConstant(m, "NSECOND", GST_NSECOND);
 
+     PyModule_AddObject(m, "CLOCK_TIME_NONE", PyLong_FromUnsignedLongLong(GST_CLOCK_TIME_NONE));
+
      /* LinkError exception */
      PyGstExc_LinkError = PyErr_NewException("gst.LinkError",
 					     PyExc_RuntimeError,
@@ -143,6 +148,9 @@ init_gst (void)
 
      pygst_register_classes (d);
      pygst_add_constants (m, "GST_");
+     /* Initialize debugging category */
+     GST_DEBUG_CATEGORY_INIT (gst_python, "python", 0,
+         "GStreamer python bindings");
 
      g_timeout_add_full (0, 100, python_do_pending_calls, NULL, NULL);
      
